@@ -1,17 +1,15 @@
 package Starch::Plugin::Net::Statsd::Manager;
-
-our $VERSION = '0.04';
+use 5.008001;
+use strictures 2;
+our $VERSION = '0.05';
 
 use Types::Common::String -types;
 use Types::Common::Numeric -types;
 
 use Moo::Role;
-use strictures 2;
 use namespace::clean;
 
-with qw(
-    Starch::Plugin::ForManager
-);
+with 'Starch::Plugin::ForManager';
 
 has statsd_host => (
     is  => 'ro',
